@@ -4,10 +4,8 @@ import logging
 import idna
 
 import requests
-import zope.interface
 
 from certbot import errors
-from certbot import interfaces
 from certbot.plugins import dns_common
 try:
     import certbot.compat.os as os
@@ -17,8 +15,6 @@ except ImportError:
 logger = logging.getLogger(__name__)
 
 
-@zope.interface.implementer(interfaces.IAuthenticator)
-@zope.interface.provider(interfaces.IPluginFactory)
 class Authenticator(dns_common.DNSAuthenticator):
     """DNS Authenticator for Infomaniak
 
